@@ -12,6 +12,7 @@ from zuper_commons.types import ZException, ZValueError
 from . import logger
 from .env_checks import check_docker_environment
 from .tee import Tee
+from .types import ContainerID, ServiceName
 
 __all__ = [
     "get_services_id",
@@ -22,8 +23,6 @@ __all__ = [
     "exit_code_for_container",
 ]
 
-from .types import ContainerID, ServiceName
-
 
 class DockerComposeFail(ZException):
     pass
@@ -42,6 +41,12 @@ def get_services_id(
             output = run_docker(wd, project, cmd, get_output=True)
         except DockerComposeFail:
             raise
+        if not output:
+            msg = "No output from docker compose"
+            raise ZValueError(
+                msg, cmd=cmd, output=output.decode(), services=services,
+            )
+
         container_ids = output.decode("utf-8").strip().split("\n")  # \n at the end
         container_ids = cast(List[ContainerID], container_ids)
         # Note: unfortunately the container_ids are not ordered
