@@ -199,10 +199,13 @@ Usage:
     if os.getpid() != 1:
         precise_str += f"-{os.getpid()}"
 
-    evaluator_name = (parsed.name or "noname") + "_" + precise_str
+    if parsed.name:
+        evaluator_name = parsed.name
+    else:
+        evaluator_name = "noname" + "_" + precise_str
 
     if parsed.machine_id:
-        machine_id = parsed.machine_id + "_" + socket.gethostname()
+        machine_id = parsed.machine_id  # + "_" + socket.gethostname()
     else:
         machine_id = socket.gethostname()
 
@@ -437,7 +440,7 @@ def upload_process(
         # noinspection PyBroadException
         try:
             # TODO:
-            more_features = {}
+            # more_features = {}
             # features = get_features(more_features, use_ipfs=False)
 
             res_ = dtserver_job_heartbeat(
