@@ -15,6 +15,7 @@ from docker import DockerClient
 from zuper_commons.fs import mkdirs_thread_safe, read_ustring_from_utf8_file, write_ustring_to_utf8_file
 from zuper_commons.text import indent
 from zuper_commons.timing import now_utc
+from zuper_commons.types import ZValueError
 
 from duckietown_build_utils import (
     BuildFailed,
@@ -105,9 +106,14 @@ def runner_local_main_(args: List[str] = None, token: str = None, docker_usernam
         logger.setLevel(logging.INFO)
 
     if parsed.change:
-        logger.debug("Running in directory %s" % os.getcwd())
+        curdir = os.getcwd()
+
+        logger.debug("Changing dir", current=curdir, to=parsed.change)
+
+        if not os.path.exists(parsed.change):
+            msg = "Cannot find dir to change to"
+            raise ZValueError(msg, curdir=curdir, tochange=parsed.change)
         os.chdir(parsed.change)
-        logger.debug("Changing to directory %s" % os.getcwd())
 
     if token is None:
         token = get_token_from_shell_config()
